package edu.travel.adapter.service.commodity;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.adapter.annotation.AdapterAnnotation;
import edu.travel.remote.commodity.ShopShoppingCartRemoteController;
import edu.travel.remote.dto.AddShopCartDto;
import edu.travel.remote.dto.BaseDto;
import edu.travel.remote.dto.UpdateShopCarDto;
import edu.travel.remote.vo.ShopCartListVo;
import edu.travel.resp.BaseResponse;
import edu.travel.rpc.RPCBaseResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Set;


@Component
public class ShopShoppingCartAdapter {
    @Autowired
    private ShopShoppingCartRemoteController shopShoppingCartRemoteController;
    /**
     *  新增购物车
     * @param params
     * @return {@link BaseResponse }<{@link Boolean }>
     */
    @AdapterAnnotation
    public RPCBaseResponse<Boolean> addShopCart(AddShopCartDto params) {
        return shopShoppingCartRemoteController.addShopCart(params);
    }

    /**
     * 分页查询购物车列表
     * @param params
     * @return {@link BaseResponse }<{@link Page }<{@link ShopCartListVo }>>
     */
    @AdapterAnnotation
    public RPCBaseResponse<Page<ShopCartListVo>> getShopCartList(BaseDto params) {
        return shopShoppingCartRemoteController.getShopCartList(params);
    }

    /**
     * 修改购物车信息
     * @param params
     * @return {@link BaseResponse }<{@link Page }<{@link ShopCartListVo }>>
     */
    @AdapterAnnotation
    public RPCBaseResponse<Boolean> updateCart(UpdateShopCarDto params) {
        return shopShoppingCartRemoteController.updateCart(params);
    }
    /**
     * 删除购物车
     * @param ids
     * @return {@link BaseResponse }<{@link Page }<{@link ShopCartListVo }>>
     */
    @AdapterAnnotation
    public RPCBaseResponse<Integer> delCart(Set<String> ids) {
        return shopShoppingCartRemoteController.delCart(ids);
    }
}
