package edu.travel.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.adapter.service.commodity.ShopFavoriteAdapter;
import edu.travel.remote.dto.AddFavoriteDto;
import edu.travel.remote.dto.BaseDto;
import edu.travel.remote.vo.ShopFavoriteVo;
import edu.travel.rpc.RPCBaseResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Set;

import static edu.travel.rpc.RPCBaseResponse.success;

/**
 * 收藏表(shop_favorite)表控制层
 *
 * @author xxxxx
 */
@RestController
@RequestMapping("/shopFavorite")
public class ShopFavoriteController {

    @Autowired
    private ShopFavoriteAdapter shopFavoriteAdapter;

    /**
     *  获取收藏商品
     * @return {@link RPCBaseResponse }<{@link Page }<{@link ShopFavoriteVo }>>
     */
    @GetMapping("/getFavorite")
    public RPCBaseResponse<Page<ShopFavoriteVo>> getFavorite(BaseDto baseDto){
        return shopFavoriteAdapter.getFavorite(baseDto);
    }


    /**
     *  添加收藏
     * @param params
     * @return {@link RPCBaseResponse }<{@link Void }>
     */

    @PostMapping("/addFavorite")
    public RPCBaseResponse<Void> addFavorite(@RequestBody AddFavoriteDto params){
        shopFavoriteAdapter.addFavorite(params);
        return success();
    }

    /**
     * 移除收藏
     */
    @PostMapping("/removeFavorite")
    public RPCBaseResponse<Void> removeFavorite(@RequestBody Set<String> ids){
        shopFavoriteAdapter.removeFavorite(ids);
        return success();
    }

    /**
     * 全部移除
     */
    @PostMapping("/removeAllFavorite")
    public RPCBaseResponse<Void> removeAllFavorite(){
        shopFavoriteAdapter.removeAllFavorite();
        return success();
    }
}
