package edu.travel.tenant;

import edu.travel.remote.base.RemoteBaseController;
import edu.travel.remote.feign.mode.dto.tenant.AddOrUpdateRoleDto;
import edu.travel.remote.feign.mode.dto.tenant.AssignRolesOrMenusDto;
import edu.travel.remote.feign.mode.dto.tenant.SysRoleDto;
import edu.travel.remote.feign.mode.dto.tenant.SysRolePageDto;
import edu.travel.remote.feign.mode.vo.tenant.SysRoleVo;
import edu.travel.resp.BaseResponse;
import edu.travel.rpc.RPCBaseResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "tenant-dev",path = "/sysRole")
public interface SysRoleRemoteController extends RemoteBaseController<SysRoleVo, SysRoleDto> {
    /**
     * 通过id查找角色
     */
    @GetMapping("/getFormId")
    public RPCBaseResponse<SysRoleVo> getFormId(@RequestParam("id") String id);
    /**
     * 新增管理角色并分配菜单
     */
    @PostMapping("/addRoleAndAssignMenus")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<SysRoleVo> addRoleAndAssignMenus(@RequestBody AddOrUpdateRoleDto addOrUpdateRoleDto);

    /**
     * 删除角色多个
     */
    @PostMapping("/deleteRoleByIds")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> deleteRoleByIds(@RequestBody List<Long> ids);

    /**
     * 删除角色单个
     */
    @PostMapping("/deleteRoleById")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> deleteRoleById(@RequestParam Long id);

    /**
     * 更新角色和角色下菜单
     */
    @PostMapping("/updateRoleAndMenusById")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> updateRoleAndMenusById( @RequestBody AddOrUpdateRoleDto addOrUpdateRoleDto);

//    /**
//     * 为角色分配菜单
//     * @param dto
//     * @return
//     */
//    @PostMapping("/assignMenusToRole")
////    @PreAuthorize("hasRole('超级管理员')")
//    public BaseResponse<Boolean> assignMenusToRole(@RequestBody AssignRolesOrMenusDto dto);

    /**
     * 更新角色菜单
     * @param assignRolesOrMenusDto
     * @return
     */
    @PostMapping("/updateMenusToRole")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> updateMenusToRole(@RequestBody AssignRolesOrMenusDto assignRolesOrMenusDto);

    /**
     * 分页查询角色列表
     * @param sysRolePageDto
     * @return
     */
    @GetMapping("/getRolePageList")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<List<SysRoleVo>> getRolePageList(SysRolePageDto sysRolePageDto);
}
