package edu.travel.tenant;

import edu.travel.remote.base.RemoteBaseController;
import edu.travel.remote.feign.mode.dto.tenant.AddOrUpdateTenantDto;
import edu.travel.remote.feign.mode.dto.tenant.AssignRolesOrMenusDto;
import edu.travel.remote.feign.mode.dto.tenant.EduTenantPageDto;
import edu.travel.remote.feign.mode.vo.tenant.AdminInfoRoleMenuVo;
import edu.travel.remote.feign.mode.vo.tenant.EduTenantVo;
import edu.travel.remote.feign.mode.vo.tenant.SysRoleVo;
import edu.travel.resp.BaseResponse;
import edu.travel.rpc.RPCBaseResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Set;

@FeignClient(name = "tenant-dev",path = "/user")
public interface TenantRemoteController  extends RemoteBaseController<EduTenantVo, AddOrUpdateTenantDto> {

    @GetMapping("/getTenantByPhoneNumber")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<EduTenantVo> getTenantByPhoneNumber();

    /**
     * 新增用户
     */
    @PostMapping("/addTenant")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<EduTenantVo> addTenant(@RequestBody AddOrUpdateTenantDto addOrUpdateTenantDto);

    /**
     * 通过ids删除用户
     */
    @PostMapping("/deleteTenantByIds")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> deleteTenant(@RequestBody List<Long> ids);
    /**
     * 通过id删除用户
     */
    @PostMapping("/deleteTenantById")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> deleteTenant(Long id);

    /**
     * 修改用户信息
     */
    @PostMapping("/updateTenantById")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> updateTenant(@RequestBody AddOrUpdateTenantDto addOrUpdateTenantDto);
    /**
     * 通过id查询商城用户信息
     */
    @GetMapping("/getTenantById")
//    @PreAuthorize("hasRole('超级管理员')")
    public RPCBaseResponse<EduTenantVo> getTenantById(@RequestParam("id") Long id);
    /**
     * 通过id查询商城用户信息
     */
    @PostMapping("/getTenantByIds")
//    @PreAuthorize("hasRole('超级管理员')")
    public RPCBaseResponse<List<EduTenantVo>> getTenantByIds(@RequestBody Set<String> id);

    /**
     * 查询登录用户信息
     *
     * @return
     */
    @GetMapping("/getLoginTenantInfo")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<EduTenantVo> getLoginTenantInfo();

    /**
     * 获取用户分页列表
     */
    @GetMapping("/getTenantPageList")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<List<EduTenantVo>> getTenantList(EduTenantPageDto tenantDto);

    /**
     * 根据用户id获取用户角色列表(未分页)
     */
    @GetMapping("/getRoleListByUserId")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<List<SysRoleVo>> getRoleListByUserId();

    /**
     * 根据用户id给用户分配角色(可以多个角色)
     */
    @PostMapping("/assignRolesToUser")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> assignRolesToUser(@RequestBody AssignRolesOrMenusDto assignRolesOrMenusDto);

    /**
     * 根据用户id给用户修改角色(可以多个角色)
     */
    @PostMapping("updateRolesToUser")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> updateRolesToUser(@RequestBody AssignRolesOrMenusDto assignRolesOrMenusDto);

    /**
     * 获取管理用户的信息、角色列表、菜单树形
     */
    @GetMapping("/getTenantInfoRoleListMenuTree")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<AdminInfoRoleMenuVo> getTenantInfoRoleListMenuTree();
    /**
     * 单个禁用用户
     */
    @PostMapping("/disableTenantById")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> disableTenantById(Long id);

    /**
     * 单个启用用户
     */
    @PostMapping("/enableTenantById")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> enableTenantById(Long id);
    /**
     * 批量启用用户
     */
    @PostMapping("/enableTenantByIds")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> enableTenantByIds(@RequestBody List<Long> ids);

    /**
     * 批量禁用用户
     */
    @PostMapping("/disableTenantByIds")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> disableTenantByIds(@RequestBody List<Long> ids);
}
