package edu.travel.commodity.web;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.FileTypeUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import edu.travel.adapter.service.upload.UploadAdapter;
import edu.travel.commodity.constant.BaseConstant;
import edu.travel.commodity.entity.ShopOpinion;
import edu.travel.commodity.service.ShopOpinionService;
import edu.travel.commodity.utils.FIleUtil;
import edu.travel.remote.commodity.ShopOpinionRemoteController;
import edu.travel.remote.dto.ShopOpinionDto;
import edu.travel.remote.upload.dto.EduFileDTO;
import edu.travel.remote.upload.vo.FileVo;
import edu.travel.remote.vo.FileWebVo;
import edu.travel.remote.vo.ShopOpinionVo;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.web.BaseController;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.*;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.multipart.MultipartFile;

import java.util.Date;
import java.util.List;

import static edu.travel.rpc.RPCBaseResponse.error;
import static edu.travel.rpc.RPCBaseResponse.success;

/**
* 意见表(shop_opinion)表控制层
*
* @author xxxxx
*/
@RestController
@RequestMapping("/shopOpinion")
public class ShopOpinionController extends BaseController<ShopOpinion> implements ShopOpinionRemoteController {
/**
* 服务对象
*/
    @Autowired
    private ShopOpinionService shopOpinionService;
    @Autowired
    private UploadAdapter uploadAdapter;
    /**
     * 分页查询（连表）
     */
    @GetMapping("/getAllFormPage")
    public RPCBaseResponse<IPage<ShopOpinionVo>> getAllFormPage(ShopOpinionDto dto) {
        return shopOpinionService.getAllFormPage(dto);
     }
    /**
     *获取意见
     */
    @Override
    @GetMapping("/getFormId")
    public RPCBaseResponse<ShopOpinionVo> getFormId(String id) {
        RPCBaseResponse<ShopOpinion> shopOpinionRPCBaseResponse = super.getId(id);
        RPCBaseResponse<ShopOpinionVo> shopOpinionVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopOpinionRPCBaseResponse, shopOpinionVoRPCBaseResponse);
        return shopOpinionVoRPCBaseResponse;
    }

    /**
     * 更新意见
     */
    @Override
    @PostMapping("/updateTargetFormId")
    public RPCBaseResponse<ShopOpinionVo> updateTargetFormId(ShopOpinionDto entity) {
        ShopOpinion shopOpinion = new ShopOpinion();
        BeanUtils.copyProperties(entity, shopOpinion);
        RPCBaseResponse<ShopOpinion> shopOpinionRPCBaseResponse = super.updateTargetById(shopOpinion);
        RPCBaseResponse<ShopOpinionVo> shopOpinionVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopOpinionRPCBaseResponse, shopOpinionVoRPCBaseResponse);
        return shopOpinionVoRPCBaseResponse;
    }

    /**
     * 新增意见
     */
    @Override
    @PostMapping("/saveFormTarget")
    public RPCBaseResponse<ShopOpinionVo> saveFormTarget(ShopOpinionDto entity) {
        ShopOpinion shopOpinion = new ShopOpinion();
        BeanUtils.copyProperties(entity, shopOpinion);
        RPCBaseResponse<ShopOpinion> shopOpinionRPCBaseResponse = super.saveTarget(shopOpinion);
        RPCBaseResponse<ShopOpinionVo> shopOpinionVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopOpinionRPCBaseResponse, shopOpinionVoRPCBaseResponse);
        return shopOpinionVoRPCBaseResponse;
    }

    /**
     * 删除意见
     */
    @Override
    @PostMapping("/deleteTargetFormId")
    public RPCBaseResponse<ShopOpinionVo> deleteTargetFormId(List<String> ids) {
        RPCBaseResponse<ShopOpinion> shopOpinionRPCBaseResponse = super.deleteTargetById(ids);
        RPCBaseResponse<ShopOpinionVo> shopOpinionVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopOpinionRPCBaseResponse, shopOpinionVoRPCBaseResponse);
        return shopOpinionVoRPCBaseResponse;
    }

    /**
     * 获取所有意见
     */
    @Override
    @GetMapping("/getAllForm")
    public RPCBaseResponse<List<ShopOpinionVo>> getAllForm() {
        RPCBaseResponse<List<ShopOpinion>> countryRPCBaseResponse = super.listAll();
        RPCBaseResponse<List<ShopOpinionVo>> baseCountryVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(countryRPCBaseResponse, baseCountryVoRPCBaseResponse);
        return baseCountryVoRPCBaseResponse;
    }

    /**
     * 意见图片上传
     */
    @PostMapping("/uploadOpinionImage")
    public RPCBaseResponse<FileWebVo> uploadOpinionImage(MultipartFile file) {
        if (file == null || file.isEmpty()) {
            return error();
        }
        try {
            // 通过文件的字节流获取真实类型（Hutool自动解析魔数）
            String fileType = FileTypeUtil.getType(file.getInputStream());
            // 判断类型是否在支持的图片类型集合中
            if (fileType != null && BaseConstant.getOpinionFileTypes().contains(fileType.toLowerCase())) {
                String filename = file.getOriginalFilename();
                if(ObjectUtil.isEmpty(filename)){
                    return error();
                }
                RPCBaseResponse<String> stringRPCBaseResponse = uploadAdapter.initializeUpload();

                EduFileDTO eduFileDTO = new EduFileDTO();
                eduFileDTO.setUploadId(stringRPCBaseResponse.getData());
                eduFileDTO.setFileType(fileType);
                eduFileDTO.setFileName(filename);
                eduFileDTO.setFileSysName(IdUtil.fastSimpleUUID()+ DateUtil.format(new Date(),"yyyyMMddHHmmss") +"."+fileType);
                eduFileDTO.setFileMd5(FIleUtil.calculateFileMd5(file.getBytes()));
                RPCBaseResponse<FileVo> fileVoRPCBaseResponse = uploadAdapter.uploadFilePath(eduFileDTO, file);
                FileWebVo bean = BeanUtil.toBean(fileVoRPCBaseResponse.getData(), FileWebVo.class);
                return success(bean);
            }
        } catch (Exception e) {
            e.printStackTrace();
            // 处理流读取异常或类型解析失败
            return error("文件上传失败");
        }
        return error();
    }



}
