package edu.travel.commodity.web;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.FileTypeUtil;
import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.adapter.service.upload.UploadAdapter;
import edu.travel.commodity.constant.BaseConstant;
import edu.travel.commodity.entity.ShopProduct;
import edu.travel.commodity.service.ShopProductService;
import edu.travel.commodity.utils.FIleUtil;
import edu.travel.commodity.utils.IdUtils;
import edu.travel.remote.commodity.ShopProductRemoteController;
import edu.travel.remote.dto.GetProductByTypeDto;
import edu.travel.remote.dto.InsertProductDto;
import edu.travel.remote.dto.SearchProductDto;
import edu.travel.remote.upload.dto.EduFileDTO;
import edu.travel.remote.upload.vo.FileVo;
import edu.travel.remote.vo.FileWebVo;
import edu.travel.resp.BaseResponse;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.remote.vo.ShopProductVo;
import edu.travel.web.BaseController;
import org.springframework.context.annotation.Bean;
import org.springframework.web.bind.annotation.*;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.Date;
import java.util.List;

import static edu.travel.rpc.RPCBaseResponse.error;
import static edu.travel.rpc.RPCBaseResponse.success;

/**
* 商品表(shop_product)表控制层
*
* @author xxxxx
*/
@RestController
@RequestMapping("/shopProduct")
public class ShopProductController extends BaseController<ShopProduct> implements ShopProductRemoteController{
/**
* 服务对象
*/
    @Autowired
    private ShopProductService shopProductService;
    @Autowired
    private UploadAdapter uploadAdapter;

    /**
     *  首页获取热门类别的热门商品
     * @param param 类型
     * @return {@link BaseResponse }<{@link List }<{@link ShopProductVo }>>
     */
    @GetMapping("/getHotProduct")
    public RPCBaseResponse<Page<ShopProductVo>> getHotProduct(GetProductByTypeDto param){
        return success(shopProductService.getHotProduct(param));
    }

    /**
     *  搜索商品
     * @param param 类型
     * @return {@link BaseResponse }<{@link List }<{@link ShopProductVo }>>
     */
    @GetMapping("/searchProduct")
    public RPCBaseResponse<Page<ShopProductVo>> searchProduct(SearchProductDto param) throws IOException {
        return success(shopProductService.searchProduct(param));
    }


    /**
     *  上传商品图片
     * @param file
     * @return {@link RPCBaseResponse }<{@link String }>
     */

    @PostMapping("/uploadProductImage")
    public RPCBaseResponse<FileWebVo> uploadProductImage(MultipartFile file){
        if (file == null || file.isEmpty()) {
            return error();
        }
        try {
            // 通过文件的字节流获取真实类型（Hutool自动解析魔数）
            String fileType = FileTypeUtil.getType(file.getInputStream());
            // 判断类型是否在支持的图片类型集合中
            if (fileType != null && BaseConstant.getProductImageTypes().contains(fileType.toLowerCase())) {
                String filename = file.getOriginalFilename();
                if(ObjectUtil.isEmpty(filename)){
                    return error();
                }
                RPCBaseResponse<String> stringRPCBaseResponse = uploadAdapter.initializeUpload();

                EduFileDTO eduFileDTO = new EduFileDTO();
                eduFileDTO.setUploadId(stringRPCBaseResponse.getData());
                eduFileDTO.setFileType(fileType);
                eduFileDTO.setFileName(filename);
                eduFileDTO.setFileSysName(IdUtil.fastSimpleUUID()+ DateUtil.format(new Date(),"yyyyMMddHHmmss") +"."+fileType);
                eduFileDTO.setFileMd5(FIleUtil.calculateFileMd5(file.getBytes()));
                RPCBaseResponse<FileVo> fileVoRPCBaseResponse = uploadAdapter.uploadFilePath(eduFileDTO, file);
                if(fileVoRPCBaseResponse.getCode()!=200){
                    return error();
                }
                FileVo data = fileVoRPCBaseResponse.getData();
                FileWebVo bean = BeanUtil.toBean(data, FileWebVo.class);
                return success("success",bean);
            }
        } catch (Exception e) {
            e.printStackTrace();
            // 处理流读取异常或类型解析失败
            return error("文件上传失败");
        }
        return error();
    }


    /**
     *  新增商品
     * @param params
     * @return {@link RPCBaseResponse }<{@link Void }>
     */

    @PostMapping("/insertProduct")
    public RPCBaseResponse<Void> insertProduct(@RequestBody InsertProductDto params){
        shopProductService.insertProduct(params);
        return success();
    }

    /**
     *  获取SkuId
     * @return {@link RPCBaseResponse }<{@link String }>
     */

    @GetMapping("/getSkuId")
    public RPCBaseResponse<String> getSkuId(){
        long id = IdUtils.getSnowflakeId();
        return success(id+"");
    }
}
