package edu.travel.commodity.web;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.commodity.entity.ShopReview;
import edu.travel.commodity.service.ShopOpinionService;
import edu.travel.commodity.service.ShopReviewService;
import edu.travel.remote.commodity.ShopReviewRemoteController;
import edu.travel.remote.dto.AddReviewDto;
import edu.travel.remote.dto.ProductSpecDto;
import edu.travel.remote.dto.ShopReviewDto;
import edu.travel.remote.vo.FileWebVo;
import edu.travel.remote.vo.ShopReviewVo;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.web.BaseController;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

import static edu.travel.rpc.RPCBaseResponse.success;


/**
 * 商品评论表(shop_review)表控制层
 *
 * @author xxxxx
 */
@RestController
@RequestMapping("/shopReview")
public class ShopReviewController extends BaseController<ShopReview> implements ShopReviewRemoteController {
    /**
     * 服务对象
     */
    @Autowired
    private ShopReviewService shopReviewService;
    @Autowired
    private ShopOpinionService shopOpinionService;

    /**
     * 获取商品评论
     *
     * @param params
     * @return {@link RPCBaseResponse }<{@link Page }<{@link ShopReviewVo }>>
     */

    @GetMapping("/getShopReview")
    public RPCBaseResponse<Page<ShopReviewVo>> getShopReview(ProductSpecDto params) {
        return success(shopReviewService.getShopReview(params));
    }

    /**
     * 发表评论
     *
     * @param params
     * @return {@link RPCBaseResponse }<{@link String }>
     */
    @PostMapping("/addReview")
    public RPCBaseResponse<String> addReview(@RequestBody AddReviewDto params) {
        return success(shopReviewService.addReview(params));
    }

    /**
     * 上传评论图片
     */
    @PostMapping("/uploadReviewImage")
    public RPCBaseResponse<FileWebVo> uploadReviewImage(MultipartFile file) {
        return shopReviewService.uploadReviewImage(file);
    }

    /**
     * 上传多张图片/视频
     */
    @PostMapping("/uploadReviewImages")
    public RPCBaseResponse<String> uploadReviewImages(List<MultipartFile> files) {
        return shopReviewService.uploadReviewImages(files);
    }

    /**
     * 通过id查找商品评论
     */
    @Override
    @GetMapping("/getFormId")
    public RPCBaseResponse<ShopReviewVo> getFormId(String id) {
        RPCBaseResponse<ShopReview> shopReviewRPCBaseResponse = super.getId(id);
        RPCBaseResponse<ShopReviewVo> shopReviewVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopReviewRPCBaseResponse, shopReviewVoRPCBaseResponse);
        return shopReviewVoRPCBaseResponse;
    }

    /**
     * 根据id更新商品评论
     */
    @Override
    @PostMapping("/updateTargetFormId")
    public RPCBaseResponse<ShopReviewVo> updateTargetFormId(ShopReviewDto entity) {
        ShopReview shopReview = new ShopReview();
        BeanUtils.copyProperties(entity, shopReview);
        RPCBaseResponse<ShopReview> shopReviewRPCBaseResponse = super.updateTargetById(shopReview);
        RPCBaseResponse<ShopReviewVo> shopReviewVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopReviewRPCBaseResponse, shopReviewVoRPCBaseResponse);
        return shopReviewVoRPCBaseResponse;
    }

    /**
     * 新增商品评论
     */
    @Override
    @PostMapping("/saveFormTarget")
    public RPCBaseResponse<ShopReviewVo> saveFormTarget(ShopReviewDto entity) {
        ShopReview shopReview = new ShopReview();
        BeanUtils.copyProperties(entity, shopReview);
        RPCBaseResponse<ShopReview> shopReviewRPCBaseResponse = super.saveTarget(shopReview);
        RPCBaseResponse<ShopReviewVo> shopReviewVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopReviewRPCBaseResponse, shopReviewVoRPCBaseResponse);
        return shopReviewVoRPCBaseResponse;
    }

    /**
     * 删除商品评论
     */
    @Override
    @PostMapping("/deleteTargetFormId")
    public RPCBaseResponse<ShopReviewVo> deleteTargetFormId(List<String> ids) {
        RPCBaseResponse<ShopReview> shopReviewRPCBaseResponse = super.deleteTargetById(ids);
        RPCBaseResponse<ShopReviewVo> shopReviewVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopReviewRPCBaseResponse, shopReviewVoRPCBaseResponse);
        return shopReviewVoRPCBaseResponse;
    }

    /**
     * 获取所有商品评论
     */
    @Override
    @GetMapping("/getAllForm")
    public RPCBaseResponse<List<ShopReviewVo>> getAllForm() {
        RPCBaseResponse<List<ShopReview>> shopReviewRPCBaseResponse = super.listAll();
        RPCBaseResponse<List<ShopReviewVo>> shopReviewVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopReviewRPCBaseResponse, shopReviewVoRPCBaseResponse);
        return shopReviewVoRPCBaseResponse;
    }
}
