package edu.travel.education.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.education.dto.AddHappyEntryDto;
import edu.travel.education.dto.HappyEntryDto;
import edu.travel.education.vo.HappyEntryVo;
import edu.travel.entity.EduTenantPO;
import edu.travel.remote.feign.mode.vo.tenant.EduTenantVo;
import edu.travel.service.SysServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Service;

import org.springframework.beans.factory.annotation.Autowired;

import edu.travel.education.mapper.HappyEntryMapper;
import edu.travel.education.entity.HappyEntry;
import edu.travel.education.service.HappyEntryService;
import org.springframework.transaction.annotation.Transactional;

import java.sql.Time;
import java.util.Date;
import java.util.List;
import java.util.Set;

import static com.alibaba.druid.sql.visitor.SQLEvalVisitorUtils.like;

@Service
public class HappyEntryServiceImpl  extends SysServiceImpl<HappyEntryMapper, HappyEntry> implements HappyEntryService{


    @Override
    @Transactional
    public HappyEntryVo addHappyEntry(AddHappyEntryDto happyEntryDto) {



        Assert.isTrue(ObjectUtil.isNotEmpty(happyEntryDto),"参数不能为空");
        Assert.isFalse(happyEntryDto.getMaxAge()< happyEntryDto.getMinAge(),"最大年龄必须大于等于最小年龄");
        HappyEntry entity = BeanUtil.copyProperties(happyEntryDto, HappyEntry.class);
        boolean save = this.save(entity);
        Assert.isTrue(save,"保存失败");
        return BeanUtil.copyProperties(entity, HappyEntryVo.class);
    }

    @Override
    public HappyEntryVo getHappyEntryById(Long id) {
        Assert.isTrue(ObjectUtil.isNotEmpty(id),"参数不能为空");
        HappyEntry happyEntry = this.getOneLink(new LambdaQueryWrapper<HappyEntry>().eq(HappyEntry::getId,id));
        return happyEntry==null?null:BeanUtil.copyProperties(happyEntry,HappyEntryVo.class);
    }

    @Override
    @Transactional
    public HappyEntryVo UpdateHappyEntryById(HappyEntryDto happyEntryDto) {

        Assert.isTrue(ObjectUtil.isNotEmpty(happyEntryDto),"参数不能为空");
        HappyEntry happyEntry = this.getById(happyEntryDto.getId());
        Assert.isTrue(ObjectUtil.isNotEmpty(happyEntry),"该记录不存在");

        HappyEntry entry = new HappyEntry();
        entry.setId(happyEntryDto.getId());
        entry.setSurname(happyEntryDto.getSurname());
        entry.setName(happyEntryDto.getName());
        entry.setPhone(happyEntryDto.getPhone());
        entry.setAreaCode(happyEntryDto.getAreaCode());
        entry.setEmail(happyEntryDto.getEmail());
        entry.setCourseType(happyEntryDto.getCourseType());
        entry.setMinAge(happyEntryDto.getMinAge());
        entry.setMaxAge(happyEntryDto.getMaxAge());
        entry.setUpdateTime(new Date());
        EduTenantPO principal = (EduTenantPO) SecurityContextHolder.getContext().getAuthentication().getPrincipal();
        entry.setUpdateUserId(principal.getId().toString());

        boolean update = this.update(entry, new LambdaQueryWrapper<HappyEntry>().eq(HappyEntry::getId, happyEntryDto.getId()));
        Assert.isTrue(update,"更新失败");
        HappyEntry oneLink = this.getOneLink(new LambdaQueryWrapper<HappyEntry>().eq(HappyEntry::getId, entry.getId()));

        return BeanUtil.copyProperties(oneLink,HappyEntryVo.class);
    }

    @Override
    @Transactional
    public void deleteHappyEntryByIds(Set<Long> set) {
        Assert.isTrue(ObjectUtil.isNotEmpty(set),"参数不能为空");
        List<HappyEntry> list = this.list(new LambdaQueryWrapper<HappyEntry>().in(HappyEntry::getId, set));
        Assert.isTrue(ObjectUtil.isNotEmpty(list),"包含不存在的记录");
        Assert.isTrue(ObjectUtil.equals(list.size(), set.size()),"包含不存在的记录");

        boolean b = this.removeByIds(set);
        Assert.isTrue(b,"删除失败");

    }

    @Override
    @Transactional
    public IPage<HappyEntry> listPageHappyEntry(HappyEntryDto happyEntryDto) {
        Assert.isTrue(ObjectUtil.isNotEmpty(happyEntryDto),"参数不能为空");
        IPage page = new Page(happyEntryDto.getCurrentPage() == null ? 1 : happyEntryDto.getCurrentPage(), happyEntryDto.getPageSize() == null ? 10 : happyEntryDto.getPageSize());
        LambdaQueryWrapper<HappyEntry> queryWrapper = new LambdaQueryWrapper<HappyEntry>()
                .eq(HappyEntry::getDeleteFlag, 0)
                .eq(happyEntryDto.getCourseType() != null,HappyEntry::getCourseType, happyEntryDto.getCourseType())
                .and(happyEntryDto.getMinAge() != null && happyEntryDto.getMaxAge() != null, wrapper ->
                        wrapper
                                .le(HappyEntry::getMinAge, happyEntryDto.getMaxAge())
                                .ge(HappyEntry::getMaxAge, happyEntryDto.getMinAge())
                )
                .like(happyEntryDto.getSurname() != null, HappyEntry::getSurname, happyEntryDto.getSurname())
                .like(happyEntryDto.getName() != null && !happyEntryDto.getName().isEmpty(), HappyEntry::getName, happyEntryDto.getName())
                .like(happyEntryDto.getEmail() != null && !happyEntryDto.getEmail().isEmpty(), HappyEntry::getEmail, happyEntryDto.getEmail())
                .like(happyEntryDto.getPhone() != null && !happyEntryDto.getPhone().isEmpty(), HappyEntry::getPhone, happyEntryDto.getPhone());
        IPage<HappyEntry> happyEntryIPage = this.dictMapPage(page, queryWrapper);
        return happyEntryIPage;
    }

    @Override
    public IPage<HappyEntry> dictMapPage(IPage<HappyEntry> page, LambdaQueryWrapper<HappyEntry> queryWrapper) {
        return super.getPageLink(queryWrapper,page);
    }
}
