package edu.travel.order.service.impl;


import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import edu.travel.exception.BaseException;
import edu.travel.order.entity.ShopOrder;
import edu.travel.order.entity.ShopOrderItem;
import edu.travel.order.entity.ShopOrderTypeChange;
import edu.travel.order.enums.OrderStateEnum;
import edu.travel.order.mapper.ShopOrderMapper;
import edu.travel.order.service.ShopOrderItemService;
import edu.travel.order.service.ShopOrderService;
import edu.travel.order.service.ShopOrderTypeChangeService;
import edu.travel.order.utils.PageUtil;
import edu.travel.order.utils.TokenData;
import edu.travel.remote.dto.AddOrderDto;
import edu.travel.remote.dto.GetOrderItemInfoByOrderNumDto;
import edu.travel.remote.dto.ShowOrderInfoDto;
import edu.travel.remote.vo.OrderItemVo;
import edu.travel.remote.vo.ShopSnapshotVo;
import edu.travel.remote.vo.ShowOrderInfoVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

@Service
public class ShopOrderServiceImpl extends ServiceImpl<ShopOrderMapper, ShopOrder> implements ShopOrderService {
    @Autowired
    private ShopOrderItemService shopOrderItemService;
    @Autowired
    private ShopOrderTypeChangeService shopOrderTypeChangeService;


    @Override
    public Page<ShowOrderInfoVo> showOrderInfo(ShowOrderInfoDto params) {
        String userId = TokenData.getUserId();
        LambdaQueryWrapper<ShopOrder> query = Wrappers.<ShopOrder>lambdaQuery();
        query.eq(ShopOrder::getCountryId, params.getCountryId());
        query.eq(ShopOrder::getStatus, params.getState());
        query.eq(ShopOrder::getUserId, userId);
        query.orderByDesc(ShopOrder::getCreateTime);

        Page<ShopOrder> page = page(new Page<>(params.getCurrentPage(), params.getPageSize()), query);
        Page<ShowOrderInfoVo> pageEntity = PageUtil.toPageEntity(page, ShowOrderInfoVo.class);
        List<ShowOrderInfoVo> records = pageEntity.getRecords();

        if(ObjectUtil.isEmpty(records)){
            return pageEntity;
        }
        //订单号
        Set<String> orderNums = records.stream().map(ShowOrderInfoVo::getId).collect(Collectors.toSet());
        LambdaQueryWrapper<ShopOrderItem> itemQuery = Wrappers.<ShopOrderItem>lambdaQuery();
        itemQuery.in(ShopOrderItem::getOrderId,orderNums);
        List<ShopOrderItem> list = shopOrderItemService.list();
        Map<String, List<ShopOrderItem>> itemMap =
                list.stream().collect(Collectors.groupingBy(ShopOrderItem::getOrderId));

        for (ShowOrderInfoVo record : records) {
            List<ShopOrderItem> shopOrderItems = itemMap.get(record.getOrderNumber());
            if(ObjectUtil.isNotEmpty(shopOrderItems)){
                List<OrderItemVo> orderItemVos = BeanUtil.copyToList(shopOrderItems, OrderItemVo.class);

                for (OrderItemVo orderItemVo : orderItemVos) {
                    ShopSnapshotVo bean1 = JSONUtil.toBean(orderItemVo.getSnapshot(), ShopSnapshotVo.class);
                    orderItemVo.setShopSnapshotVo(bean1);
                }
                record.setOrderItemVoList(orderItemVos);
            }
        }
        return pageEntity;
    }

    @Override
    public void addShopOrder(AddOrderDto params) {
        ShopOrder bean = BeanUtil.toBean(params, ShopOrder.class);
        save(bean);
    }

    @Override
    public Page<OrderItemVo> getOrderItemInfo(GetOrderItemInfoByOrderNumDto params) {
        LambdaQueryWrapper<ShopOrderItem> query = Wrappers.<ShopOrderItem>lambdaQuery().eq(ShopOrderItem::getOrderId, params.getOrderNum());
        Page<ShopOrderItem> page = shopOrderItemService.page(new Page<>(params.getCurrentPage(), params.getPageSize()), query);

        Page<OrderItemVo> pageEntity = PageUtil.toPageEntity(page, OrderItemVo.class);
        List<OrderItemVo> records = pageEntity.getRecords();
        if(ObjectUtil.isEmpty(records)){
            return pageEntity;
        }
        for (OrderItemVo record : records) {
            ShopSnapshotVo bean1 = JSONUtil.toBean(record.getSnapshot(), ShopSnapshotVo.class);
            record.setShopSnapshotVo(bean1);
        }
        return pageEntity;
    }

    @Override
    public ShowOrderInfoVo orderInfoByOrderNum(String orderNum) {

        LambdaQueryWrapper<ShopOrder> query = Wrappers.<ShopOrder>lambdaQuery();
        query.eq(ShopOrder::getOrderNumber, orderNum);


        ShopOrder one = getOne(query);
        if(ObjectUtil.isEmpty(one)){
            throw new BaseException("订单不存在");
        }
        ShowOrderInfoVo result = BeanUtil.toBean(one, ShowOrderInfoVo.class);

        LambdaQueryWrapper<ShopOrderItem> itemQuery = Wrappers.<ShopOrderItem>lambdaQuery();
        itemQuery.eq(ShopOrderItem::getOrderId,orderNum);
        List<ShopOrderItem> list = shopOrderItemService.list();
        List<OrderItemVo> orderItemVos = BeanUtil.copyToList(list, OrderItemVo.class);
        for (OrderItemVo orderItemVo : orderItemVos) {
            ShopSnapshotVo bean1 = JSONUtil.toBean(orderItemVo.getSnapshot(), ShopSnapshotVo.class);
            orderItemVo.setShopSnapshotVo(bean1);
        }
        result.setOrderItemVoList(orderItemVos);
        return result;
    }

    @Override
    public void changeOrderState(String orderNum, String state) {
        //修改订单状态
        LambdaQueryWrapper<ShopOrder> query = Wrappers.<ShopOrder>lambdaQuery();
        query.eq(ShopOrder::getOrderNumber, orderNum);
        query.eq(ShopOrder::getStatus, OrderStateEnum.WAITING_FOR_PAYMENT.getState());

        ShopOrder one = getOne(query);
        one.setStatus(Integer.parseInt(state));
        updateById(one);

        OrderStateEnum orderStateEnum = OrderStateEnum.fromState(Integer.parseInt(state));
        String userId = TokenData.getUserId();
        ShopOrderTypeChange shopOrderTypeChange = new ShopOrderTypeChange();
        shopOrderTypeChange.setStatus(Integer.parseInt(state));
        shopOrderTypeChange.setOrderId(orderNum);
        shopOrderTypeChange.setCreateUserId(userId);
        shopOrderTypeChange.setDescription(orderStateEnum.getName());
        shopOrderTypeChangeService.save(shopOrderTypeChange);
    }


}
