package edu.travel.tenant.web;

import com.baomidou.mybatisplus.core.metadata.IPage;
import edu.travel.remote.feign.mode.dto.tenant.BannerDto;
import edu.travel.remote.feign.mode.romote.ShopBannerRemoteController;
import edu.travel.remote.feign.mode.vo.banner.BannerVo;
import edu.travel.resp.BaseResponse;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.tenant.entity.ShopBanner;
import edu.travel.tenant.service.ShopBannerService;
import edu.travel.web.BaseController;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

import static edu.travel.rpc.RPCBaseResponse.success;

/**
* 轮播图(shop_banner)表控制层
*
* @author xxxxx
*/
@RestController
@RequestMapping("/shopBanner")
public class ShopBannerController extends BaseController<ShopBanner> implements ShopBannerRemoteController {
/**
* 服务对象
*/
    @Autowired
    private ShopBannerService shopBannerService;


    /**
     *  获取轮播图
     * @param banner
     * @return {@link BaseResponse }<{@link List }<{@link BannerVo }>>
     */
    @GetMapping("/getBanner")
    public RPCBaseResponse<List<BannerVo>> getBanner(BannerDto banner){
        return success(shopBannerService.getBanner(banner));
    }
    /**
     * 获取轮播图（连表-分页）
     */
    @GetMapping("/getBannerAllPage")
    public RPCBaseResponse<IPage<BannerVo>> getBannerAllPage(BannerDto banner){
        return shopBannerService.getBannerAllPage(banner);
    }
    /**
     * 新增轮播图（通过上传返回id自动填充）
     */
    @PostMapping("/saveBannerCountry")
    public RPCBaseResponse<BannerVo> saveBannerCountry (BannerDto banner){
        return shopBannerService.saveBannerCountry(banner);
    }
    /**
     * 更新轮播图信息（通过上传返回id自动填充）
     */
    @PostMapping("/updateBannerCountry")
    public RPCBaseResponse<BannerVo> updateBannerCountry(BannerDto banner){
        return shopBannerService.updateBannerCountry(banner);
    }
    /**
     * 上传banner图片
     * @param
     * @return
     */
    @PostMapping("/uploadBannerImage")
    public RPCBaseResponse<String> uploadBannerImage(MultipartFile file){
        return shopBannerService.uploadBannerImage(file);
    }

    /**
     * 根据id获取banner
     * @param id
     * @return
     */
    @Override
    @GetMapping("/getFormId")
    public RPCBaseResponse<BannerVo> getFormId(String id) {
        RPCBaseResponse<ShopBanner> shopBannerRPCBaseResponse = super.getId(id);
        RPCBaseResponse<BannerVo> shopBannerVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopBannerRPCBaseResponse, shopBannerVoRPCBaseResponse);
        return shopBannerVoRPCBaseResponse;
    }

    /**
     * 更新banner
     * @param entity
     * @return
     */
    @Override
    @GetMapping("/updateTargetFormId")
    public RPCBaseResponse<BannerVo> updateTargetFormId(@RequestBody BannerDto entity) {
        ShopBanner shopBanner = new ShopBanner();
        BeanUtils.copyProperties(entity, shopBanner);
        RPCBaseResponse<ShopBanner> shopBannerRPCBaseResponse = super.updateTargetById(shopBanner);
        RPCBaseResponse<BannerVo> shopBannerVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopBannerRPCBaseResponse, shopBannerVoRPCBaseResponse);
        return shopBannerVoRPCBaseResponse;
    }

    /**
     * 新增banner
     * @param entity
     * @return
     */
    @Override
    @GetMapping("/saveFormTarget")
    public RPCBaseResponse<BannerVo> saveFormTarget(BannerDto entity) {
        ShopBanner shopBanner = new ShopBanner();
        BeanUtils.copyProperties(entity, shopBanner);
        RPCBaseResponse<ShopBanner> shopBannerRPCBaseResponse = super.saveTarget(shopBanner);
        RPCBaseResponse<BannerVo> shopBannerVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopBannerRPCBaseResponse, shopBannerVoRPCBaseResponse);
        return shopBannerVoRPCBaseResponse;
    }

    /**
     * 删除轮播图
     * @param ids
     * @return
     */
    @Override
    @GetMapping("/deleteFormTarget")
    public RPCBaseResponse<BannerVo> deleteTargetFormId(List<String> ids) {
        RPCBaseResponse<ShopBanner> shopBannerRPCBaseResponse = super.deleteTargetById(ids);
        RPCBaseResponse<BannerVo> shopBannerVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopBannerRPCBaseResponse, shopBannerVoRPCBaseResponse);
        return shopBannerVoRPCBaseResponse;
    }

    /**
     * 获取所有轮播图
     * @return
     */
    @Override
    @GetMapping("/getAllForm")
    public RPCBaseResponse<List<BannerVo>> getAllForm() {
        RPCBaseResponse<List<ShopBanner>> countryRPCBaseResponse = super.listAll();
        RPCBaseResponse<List<BannerVo>> baseCountryVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(countryRPCBaseResponse, baseCountryVoRPCBaseResponse);
        return baseCountryVoRPCBaseResponse;
    }
}
